@@ -4,17 +4,17 @@ struct msg_Area
 {
    struct msg_Area *Next;
    struct Area *area;
-   ulong LowMsg;
-   ulong HighMsg;
-   ulong OldHighWater;
-   ulong HighWater;
+   uint32_t LowMsg;
+   uint32_t HighMsg;
+   uint32_t OldHighWater;
+   uint32_t HighWater;
 };
 
 bool msg_GetHighLowMsg(struct msg_Area *area);
 bool msg_WriteHighWater(struct msg_Area *area);
-bool msg_WriteMSG(struct MemMessage *mm,uchar *file);
-ulong msg_ReadCR(uchar *buf, ulong maxlen, osFile fh);
-bool msg_ExportMSGNum(struct Area *area,ulong num,bool (*handlefunc)(struct MemMessage *mm),bool isrescanning);
+bool msg_WriteMSG(struct MemMessage *mm,char *file);
+uint32_t msg_ReadCR(char *buf, uint32_t maxlen, osFile fh);
+bool msg_ExportMSGNum(struct Area *area,uint32_t num,bool (*handlefunc)(struct MemMessage *mm),bool isrescanning);
 
 struct jbList msg_AreaList;
 
@@ -68,7 +68,7 @@ bool msg_afterfunc(bool success)
 
 bool msg_importfunc(struct MemMessage *mm,struct Area *area)
 {
-   uchar buf[200],buf2[20];
+   char buf[200],buf2[20];
    struct msg_Area *ma;
 
    if(!(ma=msg_getarea(area)))
@@ -76,22 +76,22 @@ bool msg_importfunc(struct MemMessage *mm,struct Area *area)
 
    ma->HighMsg++;
 
-   sprintf(buf2,"%lu.msg",ma->HighMsg);
+   sprintf(buf2,"%u.msg",ma->HighMsg);
    MakeFullPath(ma->area->Path,buf2,buf,200);
 
    while(osExists(buf))
    {
       ma->HighMsg++;
-      sprintf(buf2,"%lu.msg",ma->HighMsg);
+      sprintf(buf2,"%u.msg",ma->HighMsg);
       MakeFullPath(ma->area->Path,buf2,buf,200);
    }
 
    return msg_WriteMSG(mm,buf);
 }
 
-bool msg_rescanfunc(struct Area *area,ulong max,bool (*handlefunc)(struct MemMessage *mm))
+bool msg_rescanfunc(struct Area *area,uint32_t max,bool (*handlefunc)(struct MemMessage *mm))
 {
-   ulong start;
+   uint32_t start;
    struct msg_Area *ma;
 
    if(!(ma=msg_getarea(area)))
@@ -118,8 +118,8 @@ bool msg_rescanfunc(struct Area *area,ulong max,bool (*handlefunc)(struct MemMes
 
 bool msg_exportfunc(struct Area *area,bool (*handlefunc)(struct MemMessage *mm))
 {
-   ulong start;
-   uchar buf[200];
+   uint32_t start;
+   char buf[200];
    struct StoredMsg Msg;
    osFile fh;
    struct msg_Area *ma;
@@ -165,15 +165,14 @@ bool msg_exportfunc(struct Area *area,bool (*handlefunc)(struct MemMessage *mm))
    return(TRUE);
 }
 
-bool msg_ExportMSGNum(struct Area *area,ulong num,bool (*handlefunc)(struct MemMessage *mm),bool isrescanning)
+bool msg_ExportMSGNum(struct Area *area,uint32_t num,bool (*handlefunc)(struct MemMessage *mm),bool isrescanning)
 {
-   ulong rlen;
-   uchar buf[200],buf2[50];
+   char buf[200],buf2[50];
    bool kludgeadd;
    osFile fh;
    struct StoredMsg Msg;
    struct MemMessage *mm;
-	ushort oldattr;
+	uint16_t oldattr;
    struct msg_Area *ma;
 
    if(!(ma=msg_getarea(area)))
@@ -182,7 +181,7 @@ bool msg_ExportMSGNum(struct Area *area,ulong num,bool (*handlefunc)(struct MemM
    if(!(mm=mmAlloc()))
       return(FALSE);
 
-   sprintf(buf2,"%lu.msg",num);
+   sprintf(buf2,"%u.msg",num);
    MakeFullPath(area->Path,buf2,buf,200);
 
    if(!(fh=osOpen(buf,MODE_OLDFILE)))
@@ -236,7 +235,7 @@ bool msg_ExportMSGNum(struct Area *area,ulong num,bool (*handlefunc)(struct MemM
 
    do
    {
-      rlen=msg_ReadCR(buf,200,fh);
+      msg_ReadCR(buf,200,fh);
 
       if(buf[0]!=1 && buf[0]!=10 && !kludgeadd)
       {
@@ -304,7 +303,7 @@ bool msg_ExportMSGNum(struct Area *area,ulong num,bool (*handlefunc)(struct MemM
    {
       scan_total++;
 
-      sprintf(buf2,"%lu.msg",num);
+      sprintf(buf2,"%u.msg",num);
       MakeFullPath(area->Path,buf2,buf,200);
 
 		if((config.cfg_Flags & CFG_ALLOWKILLSENT) && (oldattr & FLAG_KILLSENT) && (area->AreaType == AREATYPE_NETMAIL))
@@ -341,10 +340,10 @@ bool msg_ExportMSGNum(struct Area *area,ulong num,bool (*handlefunc)(struct MemM
    return(TRUE);
 }
 
-ulong msg_templowmsg;
-ulong msg_temphighmsg;
+uint32_t msg_templowmsg;
+uint32_t msg_temphighmsg;
 
-void msg_scandirfunc(uchar *file)
+void msg_scandirfunc(char *file)
 {
    if(strlen(file) > 4)
    {
@@ -367,7 +366,7 @@ bool msg_GetHighLowMsg(struct msg_Area *area)
 
       if(!osMkDir(area->area->Path))
       {
-			ulong err=osError();
+			uint32_t err=osError();
          LogWrite(1,SYSTEMERR,"Unable to create directory");
 			LogWrite(1,SYSTEMERR,"Error: %s",osErrorMsg(err));
 
@@ -380,7 +379,7 @@ bool msg_GetHighLowMsg(struct msg_Area *area)
 
    if(!osScanDir(area->area->Path,msg_scandirfunc))
    {
-		ulong err=osError();
+		uint32_t err=osError();
       LogWrite(1,SYSTEMERR,"Failed to scan directory %s",area->area->Path);
 		LogWrite(1,SYSTEMERR,"Error: %s",osErrorMsg(err));
 			
@@ -402,7 +401,7 @@ bool msg_GetHighLowMsg(struct msg_Area *area)
 bool msg_WriteHighWater(struct msg_Area *area)
 {
    osFile fh;
-   uchar buf[200];
+   char buf[200];
    struct StoredMsg Msg;
 
    if(area->HighWater > 65535)
@@ -437,7 +436,7 @@ bool msg_WriteHighWater(struct msg_Area *area)
 
    if(!(fh=osOpen(buf,MODE_NEWFILE)))
    {
-		ulong err=osError();
+		uint32_t err=osError();
       LogWrite(1,SYSTEMERR,"Failed to write Highwater mark to %s",buf);
 		LogWrite(1,SYSTEMERR,"Error: %s",osErrorMsg(err));
       return(FALSE);
@@ -457,7 +456,7 @@ bool msg_WriteHighWater(struct msg_Area *area)
    return(TRUE);
 }
 
-bool msg_WriteMSG(struct MemMessage *mm,uchar *file)
+bool msg_WriteMSG(struct MemMessage *mm,char *file)
 {
    struct StoredMsg Msg;
    struct TextChunk *chunk;
@@ -524,7 +523,7 @@ bool msg_WriteMSG(struct MemMessage *mm,uchar *file)
 
    if((config.cfg_Flags & CFG_IMPORTSEENBY) && mm->Area[0]!=0)
    {
-      uchar *sbbuf;
+      char *sbbuf;
 
       if(!(sbbuf=mmMakeSeenByBuf(&mm->SeenBy)))
       {
@@ -534,7 +533,7 @@ bool msg_WriteMSG(struct MemMessage *mm,uchar *file)
 
       if(sbbuf[0])
 		{
-         if(!osWrite(fh,sbbuf,(ulong)strlen(sbbuf)))
+         if(!osWrite(fh,sbbuf,(uint32_t)strlen(sbbuf)))
 				{ ioerror=TRUE; ioerrornum=osError(); }
 		}	
 
@@ -550,7 +549,7 @@ bool msg_WriteMSG(struct MemMessage *mm,uchar *file)
 				if(!osWrite(fh,"\x01PATH: ",7))
 					{ ioerror=TRUE; ioerrornum=osError(); }
 
-            if(!osWrite(fh,path->Path[c],(ulong)strlen(path->Path[c])))
+            if(!osWrite(fh,path->Path[c],(uint32_t)strlen(path->Path[c])))
 					{ ioerror=TRUE; ioerrornum=osError(); }
 
             if(!osWrite(fh,"\x0d",1))
@@ -568,7 +567,7 @@ bool msg_WriteMSG(struct MemMessage *mm,uchar *file)
    return(TRUE);
 }
 
-ulong msg_ReadCR(uchar *buf, ulong maxlen, osFile fh)
+uint32_t msg_ReadCR(char *buf, uint32_t maxlen, osFile fh)
 {
    /* Reads from fh until buffer full or CR */
 
