@@ -1,10 +1,11 @@
 #include <stdlib.h>
+#include <stdint.h>
 #include <string.h>
 #include <shared/types.h>
 #include <shared/mystrncpy.h>
 #include <oslib/os.h>
 
-void MakeFullPath(uchar *path,uchar *file,uchar *dest,ulong destsize)
+void MakeFullPath(char *path,char *file,char *dest,uint32_t destsize)
 {
    int d;
    char *chr;
@@ -19,7 +20,7 @@ void MakeFullPath(uchar *path,uchar *file,uchar *dest,ulong destsize)
       if(!strchr(chr,dest[d-1]))
          if(d+1 < destsize)
          {
-            dest[d++]=(uchar)chr[0];
+            dest[d++]=(char)chr[0];
             dest[d]=0;
          }
    }
@@ -28,7 +29,7 @@ void MakeFullPath(uchar *path,uchar *file,uchar *dest,ulong destsize)
       mystrncpy(&dest[d],file,destsize-d-1);
 }
 
-uchar *GetFilePart(uchar *str)
+char *GetFilePart(char *str)
 {
    int d;
    char *chr,*ret;
